fnss.traffic.trafficmatrices.TrafficMatrix.pop_flow — FNSS 0.1.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.0 documentation »

# fnss.traffic.trafficmatrices.TrafficMatrix.pop_flow

`TrafficMatrix.` `pop_flow`(origin, destination)

  Pop a flow from the traffic matrix and return the volume of the flow removed. If the flow to remove does not exist, a KeyError is raised.

  Parameters : | origin : any hashable type The origin node destination : any hashable type The destination node
  Returns : | volume : float The volume of the flow popped from the matrix
  Raises : | KeyError: : if there is no flow from the given origin to the given destination

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.0 documentation »